@@ -4,6 +4,6 @@ gjamGibbs <- function(formula, xdata, ydata, modelList){
   # xdata        - n by Q design data.frame
   # ydata        - n by S response, continuous, discrete, categorical
   
-  .gibbsLoop( formula, xdata, ydata, modelList)
+  .gjam( formula, xdata, ydata, modelList)
 }
   
